@@ -2,7 +2,7 @@
    drvbase.cpp : This file is part of pstoedit
    Basic, driver independent output routines
 
-   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -326,7 +326,7 @@ bool drvbase::pathsCanBeMerged(const PathInfo & path1, const PathInfo & path2) c
 			 && path2.currentLineType == solid && ((path1.currentShowType == fill)
 												   || (path1.currentShowType == eofill))))
 		&& (path1.numberOfElementsInPath == path2.numberOfElementsInPath)) {
-		//errf << "Pathes seem to be mergeable" << endl;
+		//errf << "Paths seem to be mergeable" << endl;
 		for (unsigned int i = 0; i < path1.numberOfElementsInPath; i++) {
 			const basedrawingelement *bd1 = path1.path[i];
 			const basedrawingelement *bd2 = path2.path[i];
@@ -339,11 +339,11 @@ bool drvbase::pathsCanBeMerged(const PathInfo & path1, const PathInfo & path2) c
 				return false;
 		}
 		if (verbose)
-			errf << "Pathes are mergeable" << endl;
+			errf << "Paths are mergeable" << endl;
 		return true;
 	} else {
 		if (verbose)
-			errf << "Pathes are not mergable:" <<
+			errf << "Paths are not mergable:" <<
 				" PI1 st " << (int) path1.currentShowType <<
 				" PI1 lt " << (int) path1.currentLineType <<
 				" PI1 el " << path1.numberOfElementsInPath <<
@@ -746,7 +746,8 @@ nrOfEntries(-1), numbers(0), offset(0)
 		// now get the numbers
 		// repeat the numbers, if number of entries is odd
 		unsigned int rep = nrOfEntries % 2;	// rep is 1 for odd numbers 0 for even
-		numbers = new float[nrOfEntries * (rep + 1)];
+		size_t len = nrOfEntries * (rep + 1);
+		numbers = new float[len];
 		unsigned int cur = 0;
 #if 1
 		for (unsigned int i = 0; i <= rep; i++) {
@@ -754,6 +755,7 @@ nrOfEntries(-1), numbers(0), offset(0)
 			while ((*pattern) && (*pattern != ']')) {
 				if (*pattern == ' ' && (*(pattern + 1) != ']')) {
 					float f = (float) atof(pattern);
+					assert(cur < len);
 					numbers[cur] = f;
 					// errf << d_numbers[cur] << endl;
 					cur++;
@@ -879,7 +881,7 @@ unsigned int drvbase::nrOfSubpaths() const
 }
 
 
-void drvbase::dumpRearrangedPathes()
+void drvbase::dumpRearrangedPaths()
 {
 	// Count the subpaths
 	unsigned int numpaths = nrOfSubpaths();
@@ -957,7 +959,7 @@ bool drvbase::close_output_file_and_reopen_in_binary_mode()
 void drvbase::beginClipPath()
 {
 	// now we start a clippath, so we need to dump
-	// all previous pathes
+	// all previous paths
 	flushOutStanding();
 	last_currentPath = currentPath;
 	currentPath = &clippath;
@@ -1029,7 +1031,7 @@ void drvbase::dumpPath(bool doFlushText)
 		// a polygon with two points is drawn as a line
 
 		// PROBLEM ! This resetting has an impact on the subsequent segments
-		// if subpathes are not supported by the backend !!!!
+		// if subpaths are not supported by the backend !!!!
 		currentPath->isPolygon = false;
 		currentPath->currentShowType = drvbase::stroke;
 	}
@@ -1083,8 +1085,8 @@ void drvbase::dumpPath(bool doFlushText)
 	}
 	if (numberOfElementsInPath() > 0) {
 
-		// nothing to do for empty pathes
-		// pathes may be empty due to a merge operation
+		// nothing to do for empty paths
+		// paths may be empty due to a merge operation
 
 		if (verbose) {
 			errf << "working on";
@@ -1134,13 +1136,13 @@ void drvbase::dumpPath(bool doFlushText)
 					show_rectangle(llx, lly, urx, ury);
 				} else {
 					if (globaloptions.simulateSubPaths)
-						dumpRearrangedPathes();
+						dumpRearrangedPaths();
 					else
 						show_or_convert_path();
 				}
 			} else {			/* PolyLine */
 				if (globaloptions.simulateSubPaths)
-					dumpRearrangedPathes();
+					dumpRearrangedPaths();
 				else
 					show_or_convert_path();
 			}
@@ -1475,11 +1477,7 @@ extern "C" DLLEXPORT DescriptionRegister * getglobalRp()
 	return &DescriptionRegister::getInstance();
 }
 
-#ifdef  BUGGYGPP
-Point Point::transform(const float * matrix) const
-#else
 Point Point::transform(const float matrix[6]) const
-#endif
 {
 	const float tx = matrix[0] * x_ + matrix[2] * y_ + matrix[4];
 	const float ty = matrix[1] * x_ + matrix[3] * y_ + matrix[5];
@@ -1493,7 +1491,7 @@ DriverDescription::DriverDescription(	const char *const s_name,
 										const char *const short_expl, 
 										const char *const long_expl, 
 										const char *const suffix_p, 
-										const bool backendSupportsSubPathes_p, 
+										const bool backendSupportsSubPaths_p, 
 										const bool backendSupportsCurveto_p, 
 										const bool backendSupportsMerging_p,	// merge a separate outline and filling of a polygon -> 1. element
 										const bool backendSupportsText_p, 
@@ -1507,7 +1505,7 @@ DriverDescription::DriverDescription(	const char *const s_name,
 	short_explanation(short_expl), 
 	long_explanation(long_expl), 
 	suffix(suffix_p), 
-	backendSupportsSubPathes(backendSupportsSubPathes_p), 
+	backendSupportsSubPaths(backendSupportsSubPaths_p), 
 	backendSupportsCurveto(backendSupportsCurveto_p), 
 	backendSupportsMerging(backendSupportsMerging_p),	// merge a separate outline and filling of a polygon -> 1. element
 	backendSupportsText(backendSupportsText_p), 
