@@ -1012,8 +1012,8 @@ void drvIDRAW::show_image(const PSImage & imageinfo)
 	imageinfo.writeIdrawImage(outf, 1.0f / IDRAW_SCALING);
 }
 
-static DriverDescriptionT < drvIDRAW > D_idraw("idraw", "Interviews draw format (EPS)", "", "idraw", false,	// if backend supports subpathes, else 0
-											   // if subpathes are supported, the backend must deal with
+static DriverDescriptionT < drvIDRAW > D_idraw("idraw", "Interviews draw format (EPS)", "", "idraw", false,	// if backend supports subpaths, else 0
+											   // if subpaths are supported, the backend must deal with
 											   // sequences of the following form
 											   // moveto (start of subpath)
 											   // lineto (a line segment)
