@@ -6,7 +6,7 @@
    Class declaration for a MAGICK++ output driver with no additional attributes
    and methods (minimal interface)
 
-   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,8 +33,9 @@
 #endif
 #endif
 #include <Magick++.h>
+
 using namespace std;
-using namespace Magick;
+
 
 class drvMAGICK : public drvbase {
 
@@ -59,10 +60,10 @@ public:
 	virtual void    show_image(const PSImage & imageinfo); 
 
 private:
-	void create_vpath(VPathList & vpath);
+	void create_vpath(Magick::VPathList & vpath);
 	int	      imgcount;
 
-	Image * imageptr; //Magick::Image meant here
+	Magick::Image * imageptr; 
 	
 };
 
