@@ -24,8 +24,6 @@
 #include I_stdio
 #include I_stdlib
 
-// #include "version.h"
-
 
 
 drvSAMPL::derivedConstructor(drvSAMPL):
@@ -258,8 +256,8 @@ void drvSAMPL::show_image(const PSImage & imageinfo)
 	}
 }
 
-static DriverDescriptionT < drvSAMPL > D_sampl("sample", "sample driver: if you do not want to see this, uncomment the corresponding line in makefile and make again", "this is a long description for the sample driver","sam", true,	// backend supports subpathes
-											   // if subpathes are supported, the backend must deal with
+static DriverDescriptionT < drvSAMPL > D_sampl("sample", "sample driver: if you do not want to see this, uncomment the corresponding line in makefile and make again", "this is a long description for the sample driver","sam", true,	// backend supports subpaths
+											   // if subpaths are supported, the backend must deal with
 											   // sequences of the following form
 											   // moveto (start of subpath)
 											   // lineto (a line segment)
